@@ -180,7 +180,7 @@ class Scheduler:
                                 "status": t_error,
                                 "filepath": file_filepath,
                                 "error": "Error in next_url",
-                                "trace": str(tb),
+                                "traceback": str(tb),
                             }
                         )
                 self.__logger.info(
@@ -221,7 +221,7 @@ class Scheduler:
                     "status": t_error,
                     "filepath": file_filepath,
                     "error": "Unknow error",
-                    "trace": str(tb),
+                    "traceback": str(tb),
                 }
             )
             await self.__jobs.update(
@@ -271,12 +271,13 @@ class Scheduler:
                 "kernels": self.getSessions(),
                 "terminals": self.getTerminals(),
             }
-            Callback().add(
-                auto_delete=False,
-                uuid=f"naas_analytics__{curdate}",
-                default_result=data,
-                no_override=True,
-            )
+            if n_env.report_callback:
+                Callback().add(
+                    auto_delete=False,
+                    uuid=f"naas_analytics__{curdate}",
+                    default_result=data,
+                    no_override=True,
+                )
         except Exception as e:
             tb = traceback.format_exc()
             self.__logger.error(
@@ -286,7 +287,7 @@ class Scheduler:
                     "filepath": "analytics",
                     "status": t_error,
                     "error": str(e),
-                    "trace": tb,
+                    "traceback": tb,
                 }
             )
 
@@ -333,7 +334,8 @@ class Scheduler:
                     "duration": duration_total,
                 }
             )
-            await self.analytics(main_uid)
+            # We disable this for now as it is not used and is therefore filling up the database.
+            # await self.analytics(main_uid)
         except Exception as e:
             tb = traceback.format_exc()
             duration_total = time.time() - all_start_time
@@ -345,7 +347,7 @@ class Scheduler:
                     "filepath": "scheduler",
                     "duration": duration_total,
                     "error": str(e),
-                    "trace": tb,
+                    "traceback": tb,
                 }
             )
         except:  # noqa: E722
@@ -359,6 +361,6 @@ class Scheduler:
                     "filepath": "scheduler",
                     "duration": duration_total,
                     "error": "Unknow error",
-                    "trace": tb,
+                    "traceback": tb,
                 }
             )
